@@ -185,7 +185,12 @@ class hexagon_grid:
                                             datax, how='intersection'),
                                 how = 'union')[['geometry']].copy()
         if hexagon_dis == True:
-            self.geosolution = final_hexa
+            final_hexa["geometry"] = final_hexa["geometry"].apply(lambda geom: geom.wkb)
+            final_hexa = final_hexa.drop_duplicates(["geometry"])
+            final_hexa["geometry"] = final_hexa["geometry"].apply(lambda geom: loads(geom))
+            pdf = gpd.overlay(gdf, final_hexa, how = 'union')
+            check_topology(pdf)
+            self.geosolution = pdf
         else:
             if self.area_threshold == None:
                 area_thres = (spacing*spacing)*0.33
